@@ -3,22 +3,15 @@ use super::*;
 #[doc=include_str!("readme.md")]
 #[derive(Debug, Clone)]
 pub struct TailwindJustifyContent {
-    kind: MaybeArbitrary,
+    kind: KeywordOnly,
 }
 
-impl<T> From<T> for TailwindJustifyContent
-where
-    T: Into<String>,
-{
-    fn from(kind: T) -> Self {
-        Self { kind: MaybeArbitrary::Standard(kind.into()) }
-    }
-}
+crate::macros::sealed::keyword_instance!(TailwindJustifyContent => "justify-content");
 
 impl Display for TailwindJustifyContent {
     fn fmt(&self, f: &mut Formatter<'_>) -> std::fmt::Result {
         match &self.kind {
-            MaybeArbitrary::Standard(s) => match s.as_str() {
+            KeywordOnly::Standard(s) => match s.as_str() {
                 "flex-start" => write!(f, "justify-start"),
                 "flex-end" => write!(f, "justify-end"),
                 "center" => write!(f, "justify-center"),
@@ -27,15 +20,7 @@ impl Display for TailwindJustifyContent {
                 "space-evenly" => write!(f, "justify-evenly"),
                 _ => write!(f, "justify-content-{}", s),
             },
-            MaybeArbitrary::Arbitrary(s) => write!(f, "justify-content-[{}]", s),
-        }
-    }
-}
-
-impl TailwindInstance for TailwindJustifyContent {
-    fn attributes(&self, _: &TailwindBuilder) -> BTreeSet<CssAttribute> {
-        css_attributes! {
-            "justify-content" => self.kind.get_properties()
+            KeywordOnly::Arbitrary(s) => write!(f, "justify-content-[{}]", s),
         }
     }
 }
@@ -43,11 +28,11 @@ impl TailwindInstance for TailwindJustifyContent {
 impl TailwindJustifyContent {
     /// https://tailwindcss.com/docs/justify-content
     pub fn parse(pattern: &[&str], arbitrary: &TailwindArbitrary) -> Result<Self> {
-        Ok(Self { kind: MaybeArbitrary::parser("ease", &check_valid)(pattern, arbitrary)? })
+        Ok(Self { kind: KeywordOnly::parser("ease", &check_valid)(pattern, arbitrary)? })
     }
     /// https://tailwindcss.com/docs/justify-content
     pub fn parse_arbitrary(arbitrary: &TailwindArbitrary) -> Result<Self> {
-        Ok(Self { kind: MaybeArbitrary::parse_arbitrary(arbitrary)? })
+        Ok(Self { kind: KeywordOnly::parse_arbitrary(arbitrary)? })
     }
 }
 
